==> jc-1.4.0.tar.gz: java/rmi/StubNotFoundException.h <==
// public class java.rmi.StubNotFoundException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 512cf355dcdeb26d java_rmi_RemoteException
// @dep_class e209bb06d2229e8d java_rmi_StubNotFoundException

// header file dependencies
// @dep_header java_rmi_RemoteException

#include "java/rmi/RemoteException.h"

#ifndef _JC_java_rmi_StubNotFoundException_H_
#define _JC_java_rmi_StubNotFoundException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_StubNotFoundException$sub_refs	_jc_java_rmi_StubNotFoundException$sub_refs;
typedef struct _jc_java_rmi_StubNotFoundException$sub_nonrefs	_jc_java_rmi_StubNotFoundException$sub_nonrefs;
typedef struct _jc_java_rmi_StubNotFoundException$refs	_jc_java_rmi_StubNotFoundException$refs;
typedef struct _jc_java_rmi_StubNotFoundException$nonrefs	_jc_java_rmi_StubNotFoundException$nonrefs;
typedef struct _jc_java_rmi_StubNotFoundException$object	_jc_java_rmi_StubNotFoundException$object;

typedef struct _jc_java_rmi_StubNotFoundException$fields_struct	_jc_java_rmi_StubNotFoundException$fields_struct;
typedef const struct _jc_java_rmi_StubNotFoundException$vmethods	_jc_java_rmi_StubNotFoundException$vmethods;
typedef const struct _jc_java_rmi_StubNotFoundException$vtable	_jc_java_rmi_StubNotFoundException$vtable;
typedef const struct _jc_java_rmi_StubNotFoundException$vtype	_jc_java_rmi_StubNotFoundException$vtype;

// Class fields structure
struct _jc_java_rmi_StubNotFoundException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_StubNotFoundException$fields_struct _jc_java_rmi_StubNotFoundException$class_fields;

// Constructors
extern void _jc_java_rmi_StubNotFoundException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_StubNotFoundException$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_rmi_StubNotFoundException$method$_init$d27a3a3f2a4ade11(_jc_env *, struct _jc_java_rmi_StubNotFoundException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Exception$object *);

// Virtual methods structure
struct _jc_java_rmi_StubNotFoundException$vmethods {
};

// Vtable
struct _jc_java_rmi_StubNotFoundException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_rmi_RemoteException$vmethods	java_rmi_RemoteException;
	_jc_java_rmi_StubNotFoundException$vmethods	java_rmi_StubNotFoundException;
};

// Vtype
struct _jc_java_rmi_StubNotFoundException$vtype {
	_jc_type			type;
	_jc_java_rmi_StubNotFoundException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_StubNotFoundException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_StubNotFoundException$refs {
    _jc_java_rmi_StubNotFoundException$sub_refs	java_rmi_StubNotFoundException;
    _jc_java_rmi_RemoteException$sub_refs	java_rmi_RemoteException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_StubNotFoundException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_StubNotFoundException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_rmi_RemoteException$sub_nonrefs	java_rmi_RemoteException;
    _jc_java_rmi_StubNotFoundException$sub_nonrefs	java_rmi_StubNotFoundException;
};

// Object instance structure
struct _jc_java_rmi_StubNotFoundException$object {
	_jc_java_rmi_StubNotFoundException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_StubNotFoundException$vtype	*vtype;
	_jc_java_rmi_StubNotFoundException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_StubNotFoundException$vtype _jc_java_rmi_StubNotFoundException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_StubNotFoundException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_StubNotFoundException$class_object;

#endif	/* _JC_java_rmi_StubNotFoundException_H_ */

==> jc-1.4.6.tar.gz: java/rmi/StubNotFoundException.h <==
// public class java.rmi.StubNotFoundException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 512cf355dcdeb26d java_rmi_RemoteException
// @dep_class e209bb06d2229e8d java_rmi_StubNotFoundException

// header file dependencies
// @dep_header java_rmi_RemoteException

#include "java/rmi/RemoteException.h"

#ifndef _JC_java_rmi_StubNotFoundException_H_
#define _JC_java_rmi_StubNotFoundException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_StubNotFoundException$sub_refs	_jc_java_rmi_StubNotFoundException$sub_refs;
typedef struct _jc_java_rmi_StubNotFoundException$sub_nonrefs	_jc_java_rmi_StubNotFoundException$sub_nonrefs;
typedef struct _jc_java_rmi_StubNotFoundException$refs	_jc_java_rmi_StubNotFoundException$refs;
typedef struct _jc_java_rmi_StubNotFoundException$nonrefs	_jc_java_rmi_StubNotFoundException$nonrefs;
typedef struct _jc_java_rmi_StubNotFoundException$object	_jc_java_rmi_StubNotFoundException$object;

typedef struct _jc_java_rmi_StubNotFoundException$fields_struct	_jc_java_rmi_StubNotFoundException$fields_struct;
typedef const struct _jc_java_rmi_StubNotFoundException$vmethods	_jc_java_rmi_StubNotFoundException$vmethods;
typedef const struct _jc_java_rmi_StubNotFoundException$vtable	_jc_java_rmi_StubNotFoundException$vtable;
typedef const struct _jc_java_rmi_StubNotFoundException$vtype	_jc_java_rmi_StubNotFoundException$vtype;

// Class fields structure
struct _jc_java_rmi_StubNotFoundException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_StubNotFoundException$fields_struct _jc_java_rmi_StubNotFoundException$class_fields;

// Constructors
extern void _jc_java_rmi_StubNotFoundException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_StubNotFoundException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_StubNotFoundException$method$_init$d27a3a3f2a4ade11(_jc_env *, struct _jc_java_rmi_StubNotFoundException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Exception$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_rmi_StubNotFoundException$vmethods {
};

// Vtable
struct _jc_java_rmi_StubNotFoundException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_rmi_RemoteException$vmethods	java_rmi_RemoteException;
	_jc_java_rmi_StubNotFoundException$vmethods	java_rmi_StubNotFoundException;
};

// Vtype
struct _jc_java_rmi_StubNotFoundException$vtype {
	_jc_type			type;
	_jc_java_rmi_StubNotFoundException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_StubNotFoundException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_StubNotFoundException$refs {
    _jc_java_rmi_StubNotFoundException$sub_refs	java_rmi_StubNotFoundException;
    _jc_java_rmi_RemoteException$sub_refs	java_rmi_RemoteException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_StubNotFoundException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_StubNotFoundException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_rmi_RemoteException$sub_nonrefs	java_rmi_RemoteException;
    _jc_java_rmi_StubNotFoundException$sub_nonrefs	java_rmi_StubNotFoundException;
};

// Object instance structure
struct _jc_java_rmi_StubNotFoundException$object {
	_jc_java_rmi_StubNotFoundException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_StubNotFoundException$vtype	*vtype;
	_jc_java_rmi_StubNotFoundException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_StubNotFoundException$vtype _jc_java_rmi_StubNotFoundException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_StubNotFoundException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_StubNotFoundException$class_object;

#endif	/* _JC_java_rmi_StubNotFoundException_H_ */
